PALM-meteo: zinterp Module Reference

PALM-meteo

Loading...
Searching...
No Matches
Functions/Subroutines | Variables
zinterp Module Reference

## Functions/Subroutines
subroutine | linear (nvar, nz, ny, nx, nhreq, ain, hin, hreq, aout, err)

## Variables
integer, parameter | wp =4
integer, parameter | iwp =4

## Function/Subroutine Documentation

## ◆ linear()

subroutine zinterp::linear | ( | integer(iwp), intent(in) | nvar,
|  | integer(iwp), intent(in) | nz,
|  | integer(iwp), intent(in) | ny,
|  | integer(iwp), intent(in) | nx,
|  | integer(iwp), intent(in) | nhreq,
|  | real(wp), dimension(1:nvar, 1:nz, 1:ny, 1:nx), intent(in) | ain,
|  | real(wp), dimension(1:nz, 1:ny, 1:nx), intent(in) | hin,
|  | real(wp), dimension(1:nhreq), intent(in) | hreq,
|  | real(wp), dimension(1:nvar, 1:nhreq, 1:ny, 1:nx), intent(out) | aout,
|  | integer(iwp), intent(out) | err
| ) |  |

## Variable Documentation

## ◆ iwp

integer, parameter zinterp::iwp =4

## ◆ wp

integer, parameter zinterp::wp =4